@@ -20,6 +20,8 @@ pub struct GitStatusConfig<'a> {
     pub untracked: &'a str,
     pub ignore_submodules: bool,
     pub disabled: bool,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub windows_starship: Option<&'a str>,
 }
 
 impl<'a> Default for GitStatusConfig<'a> {
@@ -40,6 +42,7 @@ impl<'a> Default for GitStatusConfig<'a> {
             untracked: "?",
             ignore_submodules: false,
             disabled: false,
+            windows_starship: None,
         }
     }
 }
