@@ -209,8 +209,7 @@ where
         current
     } else {
         let fill_size = term_width
-            .map(|tw| if tw > used { Some(tw - used) } else { None })
-            .flatten()
+            .and_then(|tw| if tw > used { Some(tw - used) } else { None })
             .map(|remaining| remaining / chunks.len());
         chunks
             .into_iter()
@@ -229,7 +228,7 @@ mod tests {
 
     #[test]
     fn test_all_modules_is_in_alphabetical_order() {
-        let mut sorted_modules: Vec<&str> = ALL_MODULES.iter().copied().collect();
+        let mut sorted_modules: Vec<&str> = ALL_MODULES.to_vec();
         sorted_modules.sort_unstable();
         assert_eq!(sorted_modules.as_slice(), ALL_MODULES);
     }
