@@ -1,8 +1,9 @@
 use git2::RepositoryState;
-use std::path::{Path, PathBuf};
+use std::path::PathBuf;
 
 use super::{Context, Module, RootModuleConfig};
 use crate::configs::git_state::GitStateConfig;
+use crate::context::Repo;
 use crate::formatter::StringFormatter;
 
 /// Creates a module with the state of the git repository at the current directory
@@ -14,10 +15,8 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
     let config: GitStateConfig = GitStateConfig::try_load(module.config);
 
     let repo = context.get_repo().ok()?;
-    let repo_root = repo.root.as_ref()?;
-    let repo_state = repo.state;
 
-    let state_description = get_state_description(repo_state, repo_root, &config)?;
+    let state_description = get_state_description(repo, &config)?;
 
     let parsed = StringFormatter::new(config.format).and_then(|formatter| {
         formatter
@@ -52,11 +51,10 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
 ///
 /// During a git operation it will show: REBASING, BISECTING, MERGING, etc.
 fn get_state_description<'a>(
-    state: RepositoryState,
-    root: &'a Path,
+    repo: &'a Repo,
     config: &GitStateConfig<'a>,
 ) -> Option<StateDescription<'a>> {
-    match state {
+    match repo.state {
         RepositoryState::Clean => None,
         RepositoryState::Merge => Some(StateDescription {
             label: config.merge,
@@ -98,13 +96,13 @@ fn get_state_description<'a>(
             current: None,
             total: None,
         }),
-        RepositoryState::Rebase => Some(describe_rebase(root, config.rebase)),
-        RepositoryState::RebaseInteractive => Some(describe_rebase(root, config.rebase)),
-        RepositoryState::RebaseMerge => Some(describe_rebase(root, config.rebase)),
+        RepositoryState::Rebase => Some(describe_rebase(repo, config.rebase)),
+        RepositoryState::RebaseInteractive => Some(describe_rebase(repo, config.rebase)),
+        RepositoryState::RebaseMerge => Some(describe_rebase(repo, config.rebase)),
     }
 }
 
-fn describe_rebase<'a>(root: &'a Path, rebase_config: &'a str) -> StateDescription<'a> {
+fn describe_rebase<'a>(repo: &'a Repo, rebase_config: &'a str) -> StateDescription<'a> {
     /*
      *  Sadly, libgit2 seems to have some issues with reading the state of
      *  interactive rebases. So, instead, we'll poke a few of the .git files
@@ -113,25 +111,13 @@ fn describe_rebase<'a>(root: &'a Path, rebase_config: &'a str) -> StateDescripti
      *  The following is based heavily on: https://github.com/magicmonty/bash-git-prompt
      */
 
-    let dot_git = root.join(".git");
-    let dot_git = if let Ok(conf) = std::fs::read_to_string(&dot_git) {
-        let gitdir_re = regex::Regex::new(r"(?m)^gitdir: (.*)$").unwrap();
-        if let Some(caps) = gitdir_re.captures(&conf) {
-            root.join(caps.get(1).unwrap().as_str())
-        } else {
-            dot_git
-        }
-    } else {
-        dot_git
-    };
-
     let has_path = |relative_path: &str| {
-        let path = dot_git.join(PathBuf::from(relative_path));
+        let path = repo.path.join(PathBuf::from(relative_path));
         path.exists()
     };
 
     let file_to_usize = |relative_path: &str| {
-        let path = dot_git.join(PathBuf::from(relative_path));
+        let path = repo.path.join(PathBuf::from(relative_path));
         let contents = crate::utils::read_file(path).ok()?;
         let quantity = contents.trim().parse::<usize>().ok()?;
         Some(quantity)
